==> ah-formbuilder-1.0.30.tgz: package/es/config.js <==
export default {
  hiddenFields: ['quiz', 'survey', 'list', 'section'],
  customFields: {
    "text": {
      "advance": [{
        label: 'Visibility To Employee',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "select": {
      "advance": [{
        label: 'Visibility To Employee',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "radio": {
      "advance": [{
        label: 'Visibility To Employee',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "checkbox": {
      "advance": [{
        label: 'Visibility To Employee',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "date": {
      "advance": [{
        label: 'Visibility To Employee',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "file": {
      "advance": [{
        label: 'Visibility To Employee',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "signature": {
      "advance": [{
        label: 'Visibility To Employee',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    }
  }
};

==> ah-formbuilder-1.0.92.tgz: package/es/config.js <==
export default {
  hiddenFields: ['quiz', 'survey', 'list', 'section'],
  customFields: {
    "text": {
      "advance": [{
        label: 'Visibility',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "select": {
      "advance": [{
        label: 'Visibility',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "radio": {
      "advance": [{
        label: 'Visibility',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "checkbox": {
      "advance": [{
        label: 'Visibility',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "date": {
      "advance": [{
        label: 'Visibility',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "file": {
      "advance": [{
        label: 'Visibility',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    },
    "signature": {
      "advance": [{
        label: 'Visibility',
        slug: 'visibility',
        type: 'select',
        isMultiple: false,
        options: [{
          label: 'Visible',
          value: true
        }, {
          label: 'Hidden',
          value: false
        }]
      }]
    }
  }
};
